@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2026 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -21,15 +21,18 @@
 
 #import "OFMutableTarArchiveEntry.h"
 #import "OFTarArchiveEntry+Private.h"
+#import "OFData.h"
 #import "OFDate.h"
+#import "OFDictionary.h"
 #import "OFNumber.h"
 #import "OFString.h"
 
 @implementation OFMutableTarArchiveEntry
-@dynamic fileName, POSIXPermissions, ownerAccountID, groupOwnerAccountID;
-@dynamic compressedSize, uncompressedSize, modificationDate, type;
-@dynamic targetFileName, ownerAccountName, groupOwnerAccountName, deviceMajor;
-@dynamic deviceMinor;
+@dynamic fileName, fileType, POSIXPermissions, ownerAccountID;
+@dynamic groupOwnerAccountID, compressedSize, uncompressedSize;
+@dynamic modificationDate, type, targetFileName, ownerAccountName;
+@dynamic groupOwnerAccountName, deviceMajor, deviceMinor, extendedHeader;
+@dynamic amigaProtection, amigaComment;
 /*
  * The following is optional in OFMutableArchiveEntry, but Apple GCC 4.0.1 is
  * buggy and needs this to stop complaining.
@@ -38,17 +41,18 @@
 
 + (instancetype)entryWithFileName: (OFString *)fileName
 {
-	return [[[self alloc] initWithFileName: fileName] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithFileName: fileName]);
 }
 
 - (instancetype)initWithFileName: (OFString *)fileName
 {
-	self = [super of_init];
+	self = [self of_init];
 
 	@try {
 		_fileName = [fileName copy];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -68,28 +72,33 @@
 {
 	OFString *old = _fileName;
 	_fileName = [fileName copy];
-	[old release];
+	objc_release(old);
+}
+
+- (void)setFileType: (OFArchiveEntryFileType)fileType
+{
+	_fileType = fileType;
 }
 
 - (void)setPOSIXPermissions: (OFNumber *)POSIXPermissions
 {
 	OFNumber *old = _POSIXPermissions;
-	_POSIXPermissions = [POSIXPermissions retain];
-	[old release];
+	_POSIXPermissions = objc_retain(POSIXPermissions);
+	objc_release(old);
 }
 
 - (void)setOwnerAccountID: (OFNumber *)ownerAccountID
 {
 	OFNumber *old = _ownerAccountID;
-	_ownerAccountID = [ownerAccountID retain];
-	[old release];
+	_ownerAccountID = objc_retain(ownerAccountID);
+	objc_release(old);
 }
 
 - (void)setGroupOwnerAccountID: (OFNumber *)groupOwnerAccountID
 {
 	OFNumber *old = _groupOwnerAccountID;
-	_groupOwnerAccountID = [groupOwnerAccountID retain];
-	[old release];
+	_groupOwnerAccountID = objc_retain(groupOwnerAccountID);
+	objc_release(old);
 }
 
 - (void)setCompressedSize: (unsigned long long)compressedSize
@@ -105,34 +114,41 @@
 - (void)setModificationDate: (OFDate *)modificationDate
 {
 	OFDate *old = _modificationDate;
-	_modificationDate = [modificationDate retain];
-	[old release];
+	_modificationDate = objc_retain(modificationDate);
+	objc_release(old);
 }
 
+#if OF_GCC_VERSION >= 405
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
 - (void)setType: (OFTarArchiveEntryType)type
 {
-	_type = type;
+	_fileType = type;
 }
+#if OF_GCC_VERSION >= 405
+# pragma GCC diagnostic pop
+#endif
 
 - (void)setTargetFileName: (OFString *)targetFileName
 {
 	OFString *old = _targetFileName;
 	_targetFileName = [targetFileName copy];
-	[old release];
+	objc_release(old);
 }
 
 - (void)setOwnerAccountName: (OFString *)ownerAccountName
 {
 	OFString *old = _ownerAccountName;
 	_ownerAccountName = [ownerAccountName copy];
-	[old release];
+	objc_release(old);
 }
 
 - (void)setGroupOwnerAccountName: (OFString *)groupOwnerAccountName
 {
 	OFString *old = _groupOwnerAccountName;
 	_groupOwnerAccountName = [groupOwnerAccountName copy];
-	[old release];
+	objc_release(old);
 }
 
 - (void)setDeviceMajor: (unsigned long)deviceMajor
@@ -145,6 +161,48 @@
 	_deviceMinor = deviceMinor;
 }
 
+- (void)setExtendedHeader:
+    (OFDictionary OF_GENERIC(OFString *, OFData *) *)extendedHeader
+{
+	OFMutableDictionary *old = _extendedHeader;
+	_extendedHeader = [extendedHeader mutableCopy];
+	objc_release(old);
+}
+
+- (void)setAmigaProtection: (OFNumber *)amigaProtection
+{
+	void *pool = objc_autoreleasePoolPush();
+	uint32_t tmp = OFToBigEndian32(
+	    (uint32_t)amigaProtection.unsignedLongValue);
+	OFData *data = [OFData dataWithItems: &tmp count: sizeof(tmp)];
+
+	if (_extendedHeader == nil)
+		_extendedHeader = [[OFMutableDictionary alloc] init];
+
+	[_extendedHeader setObject: data
+			    forKey: @"SCHILY.xattr.user.amiga.mode"];
+
+	objc_autoreleasePoolPop(pool);
+}
+
+- (void)setAmigaComment: (OFString *)amigaComment
+{
+	void *pool = objc_autoreleasePoolPush();
+	const char *cString = [amigaComment
+	    cStringWithEncoding: OFStringEncodingISO8859_1];
+	size_t length = [amigaComment
+	    cStringLengthWithEncoding: OFStringEncodingISO8859_1];
+	OFData *data = [OFData dataWithItems: cString count: length + 1];
+
+	if (_extendedHeader == nil)
+		_extendedHeader = [[OFMutableDictionary alloc] init];
+
+	[_extendedHeader setObject: data
+			    forKey: @"SCHILY.xattr.user.amiga.comment"];
+
+	objc_autoreleasePoolPop(pool);
+}
+
 - (void)makeImmutable
 {
 	object_setClass(self, [OFTarArchiveEntry class]);
