@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2026 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -68,6 +68,7 @@ typedef uint32_t in_addr_t;
 # endif
 #elif !defined(OF_WINDOWS) && !defined(OF_WII)
 # define closesocket(sock) close(sock)
+# define ioctlsocket(...) ioctl(__VA_ARGS__)
 #endif
 
 #ifdef OF_WII
@@ -79,6 +80,7 @@ typedef uint32_t in_addr_t;
 # define fcntl(fd, cmd, flags) net_fcntl(fd, cmd, flags)
 # define h_errno 0
 # define hstrerror(err) "unknown (no hstrerror)"
+# define ioctlsocket(...) net_ioctl(__VA_ARGS__)
 # define listen(sock, backlog) net_listen(sock, backlog)
 # define poll(fds, nfds, timeout) net_poll(fds, nfds, timeout)
 # define recv(sock, buf, len, flags) net_recv(sock, buf, len, flags)
